[![Test](https://github.com/accentdesign/accentnotifications/actions/workflows/test.yml/badge.svg)](https://github.com/accentdesign/accentnotifications/actions/workflows/test.yml)

---
**Source Code**: <a href="https://github.com/accentdesign/accentnotifications" target="_blank">https://github.com/accentdesign/accentnotifications</a>
---

## Installation

For smtp:
```bash
pip install accentnotifications[smtp]
```

For twilio sms:
```bash
pip install accentnotifications[twiliosms]
```
